embassy-usb-driver

Crates

git

Versions

default

Flavors

EndpointAllocError

Struct EndpointAllocError 

pub struct EndpointAllocError;
Allocating an endpoint failed.

This can be due to running out of endpoints, or out of endpoint memory, or because the hardware doesn’t support the requested combination of features.